betty.ancestry.has_notes module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.has_notes module

Data types for entities that have notes.

class betty.ancestry.has_notes.HasNotes

  Bases: `Entity`

  An entity that has notes associated with it.

  __init__(*args: Any, notes: Iterable[Note] | ToManyResolver[Note] | None = None, **kwargs: Any)
  notes

    A bidirectional *-to-many entity type association.